==================
Causality measures
==================

.. automodule:: elephant.causality.granger


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: gr
   :keyprefix: granger-
   :style: unsrt
